package VMOMI::DayOfWeek;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
